@@ -6,6 +6,8 @@
 
 #pragma once
 
+#include "utils.h"
+
 #include <QEventLoop>
 #include <QObject>
 
@@ -22,7 +24,6 @@ public:
     {
         return m_theDialog;
     }
-    bool exec();
 
     void create(const QString &file, const QVariantMap &props);
 
@@ -30,7 +31,11 @@ public Q_SLOTS:
     void reject();
     virtual void accept();
 
+Q_SIGNALS:
+    void finished(DialogResult result);
+    void accepted();
+    void rejected();
+
 protected:
     QWindow *m_theDialog = nullptr;
-    QEventLoop m_execLoop;
 };
